@@ -423,40 +423,6 @@ class ServerManager(base.BootingManagerWithFind):
               config_drive=None, admin_pass=None, disk_config=None, **kwargs):
         """
         Create (boot) a new server.
-
-        :param name: Something to name the server.
-        :param image: The :class:`Image` to boot with.
-        :param flavor: The :class:`Flavor` to boot onto.
-        :param meta: A dict of arbitrary key/value metadata to store for this
-                     server. A maximum of five entries is allowed, and both
-                     keys and values must be 255 characters or less.
-        :param files: A dict of files to overwrite on the server upon boot.
-                      Keys are file names (i.e. ``/etc/passwd``) and values
-                      are the file contents (either as a string or as a
-                      file-like object). A maximum of five entries is allowed,
-                      and each file must be 10k or less.
-        :param reservation_id: a UUID for the set of servers being requested.
-        :param return_raw: If True, don't try to coerce the result into
-                           a Resource object.
-        :param security_groups: list of security group names
-        :param key_name: (optional extension) name of keypair to inject into
-                         the instance
-        :param availability_zone: Name of the availability zone for instance
-                                  placement.
-        :param block_device_mapping: A dict of block device mappings for this
-                                     server.
-        :param block_device_mapping_v2: A dict of block device mappings V2 for
-                                        this server.
-        :param nics:  (optional extension) an ordered list of nics to be
-                      added to this server, with information about
-                      connected networks, fixed IPs, etc.
-        :param scheduler_hints: (optional extension) arbitrary key-value pairs
-                              specified by the client to help boot an instance.
-        :param config_drive: (optional extension) If True, enable config drive
-                             on the server.
-        :param admin_pass: admin password for the server.
-        :param disk_config: (optional extension) control how the disk is
-                            partitioned when the server is created.
         """
         body = {"server": {
             "name": name,
@@ -873,10 +839,15 @@ class ServerManager(base.BootingManagerWithFind):
                       are the file contents (either as a string or as a
                       file-like object). A maximum of five entries is allowed,
                       and each file must be 10k or less.
+        :param reservation_id: a UUID for the set of servers being requested.
+        :param min_count: (optional extension) The minimum number of
+                          servers to launch.
+        :param max_count: (optional extension) The maximum number of
+                          servers to launch.
+        :param security_groups: A list of security group names
         :param userdata: user data to pass to be exposed by the metadata
                       server this can be a file type object as well or a
                       string.
-        :param reservation_id: a UUID for the set of servers being requested.
         :param key_name: (optional extension) name of previously created
                       keypair to inject into the instance.
         :param availability_zone: Name of the availability zone for instance
